import {request} from '../../util/api'


/**
 * 用户列表
 */
export function userList(data){
  return request({
    method: "get",
    url: '/app/open/memInfo/list',
    data
  });
}

/**
 * 查看我喜欢的 喜欢我的 互相喜欢的列表
 */
export function likeList(data){
  return request({
    method: "get",
    url: '/app/memInfo/likeList',
    data
  });
}

/**
 * 获取用户详情
 */
export function userDetail(data){
  return request({
    method: "get",
    url: '/app/memInfo/detail/'+ data,
  });
}

/**
 * 获取我的用户详情
 */
export function userMyDetail(data){
  return request({
    method: "get",
    url: '/app/memInfo/myDetail/'+ data,
  });
}

/**
 * 根据token获取用户详情
 */
export function getUserInfo(){
  return request({
    method: "get",
    url: '/app/memInfo/getUserInfo',
  });
}

/**
 * 修改用户信息
 */

export function updateUser(data){
  return request({
    method: "put",
    url: '/app/memInfo/update',
    data: data,
  });
}

/**
 * 校验实名信息
 */
export function checkRealAuth(data){
  return request({
    method: "put",
    url: '/app/memInfo/checkIdCard/'+ data.businessId,
    data: data,
  });
}

// 添加关注
export function addFollow(data) {
  return request({
    url: '/app/memInfo/follow',
    data: data,
    method: 'POST',
  })
}
// 是否关注
export function isFollow(data) {
  return request({
    url: '/app/memInfo/isFollow',
    data: data,
    method: 'GET',
  })
}
// 取消关注
export function deleteFollow(data) {
  return request({
    url: '/app/memInfo/followDelete',
    data: data,
    method: 'POST',
  })
}
// 用户点赞
export function likeUser(data) {
  return request({
    url: '/app/memInfo/like',
    data: data,
    method: 'POST',
  })
}

/**
 * 排行榜
 */
export function rankList(data){
  return request({
    method: "get",
    url: '/app/open/memInfo/rank',
    data
  });
}
/**
 * 留言
 */
export function addMessage(data){
  return request({
    url: '/app/memLeaveMessage/leaveMessage',
    data: data,
    method: 'POST',
  });
}
/**
 * 获取消息列表
 */
export function messageList(data){
  return request({
    method: "get",
    url: '/app/memLeaveMessage/talkList',
    data
  });
}

/**
 * 获取对话消息
 */
export function telMessage(data){
  return request({
    method: "get",
    url: '/app/memLeaveMessage/leaveMessageDetailList',
    data,
  });
}

/**
 * 查看消费记录
 */
export function getConsumeRecord(data){
  return request({
    method: "get",
    url: '/app/memGoldCoinFlow/list',
    data,
  });
}

/**
 * 充值金币
 */
export function payGoldCoins(data){
  return request({
    method: "post",
    url: '/app/order/addGold',
    data,
  });
}

/**
 * 查询金币余额
 */
export function getBalance(data){
  return request({
    method: "get",
    url: '/app/memGoldCoinFlow/balance',
    data,
  });
}

/**
 * 拉黑
 */
export function addBlack(data){
  return request({
    method: "post",
    url: '/app/opmBlackList/add',
    data,
  });
}

/**
 * 黑名单
 */
export function getBlackList(data){
  return request({
    method: "get",
    url: '/app/opmBlackList/list',
    data
  });
}

// 取消关注
export function deleteBlack(data) {
  return request({
    url: '/app/opmBlackList/delete',
    method: 'delete',
    data
  })
}

// 删除消息记录
export function deleteTalk(data) {
  return request({
    url: '/app/memLeaveMessage/delete/'+data,
    method: 'delete',
  })
}

// 新增访问量
export function addMemTraffic(data) {
  return request({
    url: '/app/memtraffic/add',
    method: 'post',
    data: data
  })
}
// 留言未读数
export function noReadMessageAllCount() {
  return request({
    url: '/app/memLeaveMessage/noReadMessageAllCount',
    method: 'get',
  })
}
// 发送要微信请求
export function wantWeChatTask(data) {
  return request({
    url: '/app/memInfo/weChatTask',
    method: 'post',
    data: data
  })
}
// 查询要微信请求
export function getWeChatTask(data) {
  return request({
    url: '/app/memInfo/queryWeChatTaskRecord',
    method: 'get',
    data: data
  })
}

// 投诉反馈
export function addFeedBack(data) {
  return request({
    url: '/app/memFeedBack/add',
    data: data,
    method: 'POST',
  })
}

// 查询账号是否停用
export function isStopAccount() {
  return request({
    url: '/app/memInfo/getUserIsStop',
    method: 'get',
  })
}
